using System;
using System.Linq;
using System.Collections;
using System.Collections.Generic;
using MeshVR;
using SimpleJSON;
using MacGruber;
using MVR.FileManagementSecure;


namespace CheesyFX {
	public class CheesyFX_ExpressionIO : MVRScript {
        public List<DAZMorph> expressionMorphs = new List<DAZMorph>();
        public JSONStorableUrl loadURL;
        public const string BASE_DIRECTORY = "Saves/PluginData/CheesyFX/ExpressionIO";
        public override void Init(){
            FileManagerSecure.CreateDirectory(BASE_DIRECTORY);
            DAZCharacterSelector characterSelector = containingAtom.GetStorableByID("geometry") as DAZCharacterSelector;
			GenerateDAZMorphsControlUI morphControl = characterSelector.morphsControlUI;
            List<string> allMorphNames = morphControl.GetMorphDisplayNames();
            foreach(string morphName in allMorphNames){
                DAZMorph morph = morphControl.GetMorphByDisplayName(morphName);
                if(morph.region.ToLower().Contains("exp")){
                    expressionMorphs.Add(morph);
                }
            }
            loadURL = new JSONStorableUrl("loadURL", "", UILoadJSON, "jpg", true);
            loadURL.hideExtension = true;
            loadURL.setCallbackFunction -= UILoadJSON;
            loadURL.allowFullComputerBrowse = false;
            loadURL.allowBrowseAboveSuggestedPath = true;
            loadURL.SetFilePath(BASE_DIRECTORY+"/");
            loadURL.setCallbackFunction += UILoadJSON;
            CreateUI();
            
        }
        public JSONClass GetExpressionJSON(){
            JSONClass jc = new JSONClass();
            foreach(DAZMorph morph in expressionMorphs){
                jc[morph.displayName].AsFloat = morph.jsonFloat.val;
            }
            return jc;
        }
        
        public void LoadExpressionJSON(JSONClass jc){
            foreach(DAZMorph morph in expressionMorphs){
                morph.jsonFloat.val = jc[morph.displayName].AsFloat;
            }
        }

        public void CreateUI(){
            UIDynamicButton button;
            button = Utils.SetupButton(this, "Save", UISaveJSONDialog, false);
            button = Utils.SetupButton(this, "Load",  delegate {}, true);
            loadURL.RegisterFileBrowseButton(button.button);
        }

        public void UISaveJSONDialog(){
            SuperController sc = SuperController.singleton;
            sc.GetMediaPathDialog(UISaveJSON, "jpg", BASE_DIRECTORY, false, true, false, null, true, null, false, false);
            sc.mediaFileBrowserUI.SetTextEntry(true);
            if(sc.mediaFileBrowserUI.fileEntryField != null){
                string filename = DateTime.Now.ToString("yyyyMMdd_HH-mm-ss");
                sc.mediaFileBrowserUI.fileEntryField.text = filename;
                sc.mediaFileBrowserUI.ActivateFileNameField();
            }
        }

        public void UISaveJSON(string path)
        {
            if (string.IsNullOrEmpty(path))
                return;
            string path1 = path.Replace('\\', '/')+".eIO";
            JSONClass jc = GetExpressionJSON();
            SaveJSON(jc, path1);
            SuperController.singleton.DoSaveScreenshot(path+".jpg");
        }

        public void UILoadJSON(string url){
            JSONClass jc = LoadJSON(url.Replace(".jpg",".eIO")).AsObject;
            if(jc != null) LoadExpressionJSON(jc);
        }
    }
}